aboutsummaryrefslogtreecommitdiffstats
path: root/components
diff options
context:
space:
mode:
authorRay Clanan <rclanan@utopianconcept.com>2014-10-22 02:59:53 -0400
committerRay Clanan <rclanan@utopianconcept.com>2014-10-23 21:33:32 -0400
commit85f746f9b97236efcb7663a57f18286f78d2f5b1 (patch)
tree6ca20db0da28ae7594b79ab8ce058d38ab4f02be /components
parentd1a1ac7e28d682c9e591d7fbd9f4414a12e827c5 (diff)
downloadservo-85f746f9b97236efcb7663a57f18286f78d2f5b1.tar.gz
servo-85f746f9b97236efcb7663a57f18286f78d2f5b1.zip
Rename untraceable!() to no_jsmanaged_fields!(). References issue #3671
Diffstat (limited to 'components')
-rw-r--r--components/script/dom/bindings/DESIGN.md2
-rw-r--r--components/script/dom/bindings/trace.rs42
-rw-r--r--components/script/dom/macros.rs2
-rw-r--r--components/script/dom/node.rs2
-rw-r--r--components/script/dom/worker.rs2
-rw-r--r--components/script/script_task.rs2
6 files changed, 26 insertions, 26 deletions
diff --git a/components/script/dom/bindings/DESIGN.md b/components/script/dom/bindings/DESIGN.md
index 59b8f1de3de..2dc54c74548 100644
--- a/components/script/dom/bindings/DESIGN.md
+++ b/components/script/dom/bindings/DESIGN.md
@@ -17,7 +17,7 @@ The outline is:
This is typically derived via a #[jstraceable] annotation.
3. For all fields, `Foo::trace()`
calls `trace()` on the field. For example, for fields of type `JS<T>`, `JS<T>::trace()` calls
- `trace_reflector()`. Non-JS-managed types have an empty inline `trace()` method, achieved via `untraceable!` or similar.
+ `trace_reflector()`. Non-JS-managed types have an empty inline `trace()` method, achieved via `no_jsmanaged_fields!` or similar.
4. `trace_reflector()` fetches the reflector that is reachable from a Rust object and notifies it to the GC using JSTracer.
5. This operation continues for the rest of the graph.
6. Finally, the GC checks whether the Rust object lives or not from `JSObject`s which are held by Rust object.
diff --git a/components/script/dom/macros.rs b/components/script/dom/macros.rs
index db2d83246ce..540da5efb5f 100644
--- a/components/script/dom/macros.rs
+++ b/components/script/dom/macros.rs
@@ -164,7 +164,7 @@ macro_rules! make_uint_setter(
/// For use on non-jsmanaged types
/// Use #[jstraceable] on JS managed types
-macro_rules! untraceable(
+macro_rules! no_jsmanaged_fields(
($($ty:ident),+) => (
$(
impl JSTraceable for $ty {
diff --git a/components/script/dom/node.rs b/components/script/dom/node.rs
index e3e7ef15bad..d13feb5193e 100644
--- a/components/script/dom/node.rs
+++ b/components/script/dom/node.rs
@@ -201,7 +201,7 @@ pub struct LayoutDataRef {
pub data_cell: RefCell<Option<LayoutData>>,
}
-untraceable!(LayoutDataRef)
+no_jsmanaged_fields!(LayoutDataRef)
impl LayoutDataRef {
pub fn new() -> LayoutDataRef {
diff --git a/components/script/dom/worker.rs b/components/script/dom/worker.rs
index 9287037f561..9bacf26a36f 100644
--- a/components/script/dom/worker.rs
+++ b/components/script/dom/worker.rs
@@ -29,7 +29,7 @@ use std::cell::Cell;
use std::ptr;
pub struct TrustedWorkerAddress(pub *const c_void);
-untraceable!(TrustedWorkerAddress)
+no_jsmanaged_fields!(TrustedWorkerAddress)
#[dom_struct]
pub struct Worker {
diff --git a/components/script/script_task.rs b/components/script/script_task.rs
index 363b7ea75cf..f07fff94983 100644
--- a/components/script/script_task.rs
+++ b/components/script/script_task.rs
@@ -113,7 +113,7 @@ pub enum ScriptMsg {
#[deriving(Clone)]
pub struct ScriptChan(pub Sender<ScriptMsg>);
-untraceable!(ScriptChan)
+no_jsmanaged_fields!(ScriptChan)
impl ScriptChan {
/// Creates a new script chan.
diff --git a/components/script/dom/bindings/trace.rs b/components/script/dom/bindings/trace.rs
index a7fffe4a11e..930fd59edbe 100644
--- a/components/script/dom/bindings/trace.rs
+++ b/components/script/dom/bindings/trace.rs
@@ -22,7 +22,7 @@
//! 5. `trace_object()` calls `JS_CallTracer()` to notify the GC, which will
//! add the object to the graph, and will trace that object as well.
//!
//! The untraceable!() macro adds an empty implementation of JSTraceable to
//! a datatype.
use dom::bindings::js::JS;
@@ -64,7 +64,7 @@ impl<T: Reflectable> JSTraceable for JS<T> {
}
}
-untraceable!(Reflector)
+no_jsmanaged_fields!(Reflector)
/// A trait to allow tracing (only) DOM objects.
pub trait JSTraceable {
@@ -142,7 +142,7 @@ impl JSTraceable for JSVal {
}
// XXXManishearth Check if the following three are optimized to no-ops
-// if e.trace() is a no-op (e.g it is an untraceable type)
+// if e.trace() is a no-op (e.g it is an no_jsmanaged_fields type)
impl<T: JSTraceable> JSTraceable for Vec<T> {
#[inline]
fn trace(&self, trc: *mut JSTracer) {
@@ -153,7 +153,7 @@ impl<T: JSTraceable> JSTraceable for Vec<T> {
}
// XXXManishearth Check if the following three are optimized to no-ops
-// if e.trace() is a no-op (e.g it is an untraceable type)
+// if e.trace() is a no-op (e.g it is an no_jsmanaged_fields type)
impl<T: JSTraceable + 'static> JSTraceable for SmallVec1<T> {
#[inline]
fn trace(&self, trc: *mut JSTracer) {
@@ -190,25 +190,25 @@ impl<A: JSTraceable, B: JSTraceable> JSTraceable for (A, B) {
}
-untraceable!(bool, f32, f64, String, Url)
-untraceable!(uint, u8, u16, u32, u64)
-untraceable!(int, i8, i16, i32, i64)
-untraceable!(Sender<T>)
-untraceable!(Receiver<T>)
-untraceable!(ImageCacheTask, ScriptControlChan)
-untraceable!(Atom, Namespace, Timer)
-untraceable!(PropertyDeclarationBlock)
+no_jsmanaged_fields!(bool, f32, f64, String, Url)
+no_jsmanaged_fields!(uint, u8, u16, u32, u64)
+no_jsmanaged_fields!(int, i8, i16, i32, i64)
+no_jsmanaged_fields!(Sender<T>)
+no_jsmanaged_fields!(Receiver<T>)
+no_jsmanaged_fields!(ImageCacheTask, ScriptControlChan)
+no_jsmanaged_fields!(Atom, Namespace, Timer)
+no_jsmanaged_fields!(PropertyDeclarationBlock)
// These three are interdependent, if you plan to put jsmanaged data
// in one of these make sure it is propagated properly to containing structs
-untraceable!(SubpageId, WindowSizeData, PipelineId)
-untraceable!(QuirksMode)
-untraceable!(Cx)
-untraceable!(ResponseHeaderCollection, RequestHeaderCollection, Method)
-untraceable!(ConstellationChan)
-untraceable!(LayoutChan)
-untraceable!(WindowProxyHandler)
-untraceable!(UntrustedNodeAddress)
-untraceable!(LengthOrPercentageOrAuto)
+no_jsmanaged_fields!(SubpageId, WindowSizeData, PipelineId)
+no_jsmanaged_fields!(QuirksMode)
+no_jsmanaged_fields!(Cx)
+no_jsmanaged_fields!(ResponseHeaderCollection, RequestHeaderCollection, Method)
+no_jsmanaged_fields!(ConstellationChan)
+no_jsmanaged_fields!(LayoutChan)
+no_jsmanaged_fields!(WindowProxyHandler)
+no_jsmanaged_fields!(UntrustedNodeAddress)
+no_jsmanaged_fields!(LengthOrPercentageOrAuto)
impl<'a> JSTraceable for &'a str {
#[inline]
@@ -22,7 +22,7 @@
//! add the object to the graph, and will trace that object as well.
//!
-//! The untraceable!() macro adds an empty implementation of JSTraceable to
+//! The no_jsmanaged_fields!() macro adds an empty implementation of JSTraceable to
//! a datatype.
use dom::bindings::js::JS;